@@ -1,16 +1,12 @@
-#' @name elev
+#' @name elev.tif
 #' @title Artificial elevation raster data set
 #'
 #' @description The raster data represents elevation in meters and uses WGS84 as
 #'   a coordinate reference system.
 #' @docType data
 #' @keywords datasets raster
-#' @importClassesFrom raster RasterLayer
 #' 
 #' @examples 
-#' if (requireNamespace("raster", quietly = TRUE)) {
-#'   library(raster)
-#'   data(elev)
-#'   elev
-#' }
-"elev"
+#' system.file("raster/elev.tif", package = "spData")
+NULL
+
